@@ -1,4 +1,5 @@
 from .imports import *
+from . import _utils
 
 def login(self):
     headers = {
@@ -61,11 +62,42 @@ def login(self):
     if not successful:
         raise Exception("Kunne ikke finde elev id. Rapporter venligst dette på Github")
 
-    self.session.headers.update({"content-type": "application/x-www-form-urlencoded"})
-
-
 def base64Cookie(self):
-    cookie = self.session.cookies.get_dict()
-    cookie["LastLoginElevId"] = self.elevId
+    #cookie = self.session.cookies.get_dict()
+    cookie = []
+    for _cookie in self.session.cookies:
+        __cookie = str(_cookie).replace("<Cookie ", "").replace("/>", "").replace(">", "").split(" for ")
+        cookie.append({
+            "name": __cookie[0].split("=")[0],
+            "value": __cookie[0].split("=")[1],
+            "for": __cookie[1]
+        })
 
-    return base64.b64encode(json.dumps(cookie).encode())
\ No newline at end of file
+    cookie.append({
+        "name": "LastLoginElevId",
+        "value": self.elevId,
+        "for": "www.lectio.dk/"
+    })
+
+    cookie.append({
+        "name": "LastLoginExamno",
+        "value": self.skoleId,
+        "for": "www.lectio.dk/"
+    })
+
+    return base64.b64encode(json.dumps(cookie).encode()).decode()
+
+def qrLogin(self, userId, QrId):
+    resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/LandingPageQrCode.aspx?userId={userId}&QrId={QrId}")
+    soup = BeautifulSoup(resp.text, "html.parser")
+    if "Fejl: Der opstod en fejl" in resp.text:
+        raise Exception("Den scannede QR kode er ikke valid. En QR kode er kun gyldig i 90 sekunder og kan kun bruges én gang. - Generér en ny og prøv igen eller log ind manuelt.")
+
+    successful = False
+    for meta in soup.find_all({"meta": {"name": "msapplication-starturl"}}):
+        if f"/lectio/{self.skoleId}/forside.aspx?" in str(meta.get("content")):
+            self.elevId = meta.get("content").split("?elevid=")[1]
+            successful = True
+            break
+    if not successful:
+        raise Exception("Kunne ikke finde elev id. Rapporter venligst dette på Github")
\ No newline at end of file
